pub struct Usage {
pub input_tokens: u32,
pub output_tokens: u32,
}Expand description
Token usage accounting for the evaluation request.
Required per the Jev wire specification.
Fields
input_tokens: u32Number of tokens in the input state and question instructions.
output_tokens: u32Number of tokens accounted to generating the evaluated judgments.